@@ -318,7 +318,11 @@ class XBuffer(ABC):
 
     @abstractmethod
     def to_nplike(self, offset, dtype, shape):
-        """Return a view in of an nplike"""
+        """Return a view in a nplike"""
+
+    @abstractmethod
+    def to_nparray(self, offset, dtype, shape):
+        """Return a view or copy in a numpy array"""
 
     @abstractmethod
     def update_from_nplike(self, offset, dest_dtype, value):
@@ -445,7 +449,7 @@ def get_context_from_string(ctxstr):
     import xobjects as xo
 
     if ctxstr is None:
-        return xo.ContexCPU()
+        return xo.ContextCpu()
     else:
         ll = ctxstr.split(":")
         if len(ll) <= 1:
